#!/usr/bin/env python3
import os.path
import subprocess
import sys
import unittest
sys.path.insert(0, "..")

from src.AppMetadata import extract_metadata

ARCHIVE = "archive"
SUITE = "test"
ARCHS = ("foo", "bar")
OUT_DIR = "output/"

APPLICATIONS = {
  "foreign-icon-app.desktop": ("Name", "Foreign Icon App"),
  "usr_share_applications_a_standard-app.desktop": ("Name", "Standard App"),
  "standard-app.desktop": ("Name", "Standard App"),
  "no-icon-app.desktop": ("X-AppInstall-Package", "no-icon-app"),
  "rel-path-alt.desktop": ("Icon", "rel-path-alt"),
  "rel-path-app.desktop": ("Icon", "rel-path-app"),
  "symlink-icon-app.desktop":
  ("Icon", "_usr_share_icons_symlink-to-usrlibsym_symlink-icon-app")}

ICONS = (
  "foreign-icon.png", "rel-path-alt.png",
  "rel-path-app.png", "standard-app.png",
  "_usr_share_icons_symlink-to-usrlibsym_symlink-icon-app.png")


class TestExtractMetadata(unittest.TestCase):
    """
    Tests the proper operation of extract_metadata(), the main function
    of this codebase, which extracts app-install and command-not-found
    data.
    """
    @classmethod
    def setUpClass(self):
        extract_metadata(ARCHIVE, SUITE, ARCHS, OUT_DIR, 500)

    def test_full_run_apps(self):
        """extract_metadata() extracts apps from test archive"""
        # check that the right entry files were extracted
        extracted = os.listdir(os.path.join(OUT_DIR, "desktop/"))
        self.assertCountEqual(extracted, APPLICATIONS.keys())
        # for all entries, ensure the contents have a particular
        # key->value combination as listed in APPLICATIONS.
        for desktop in extracted:
            passed = False
            path = os.path.join(OUT_DIR, "desktop", desktop)
            with open(path, "r") as f:
                lines = f.readlines()
            test_elem, test_value = APPLICATIONS[desktop]
            for line in lines:
                if line.startswith(test_elem):
                    tag, name = line.strip().split("=")
                    self.assertEqual(name, test_value)
                    passed = True
                    break
            self.assertTrue(passed)

    def test_full_run_icons(self):
        """extract_metadata() extracts icons from test archive"""
        extracted = os.listdir(os.path.join(OUT_DIR, "icons/"))
        self.assertCountEqual(extracted, ICONS)

if __name__ == "__main__":
    subprocess.call("./build_test_archive")
    unittest.main()
