#!/usr/bin/env python3
import hashlib
import os.path
import subprocess
import sys
import unittest

sys.path.insert(0, "..")
from src.ArchiveCache import ArchiveCache
from src.IconFinder import IconFinder

RELEASE_PATH = "archive/dists/test/Release"
STANDARD_ICON_MD5 = "f0aa9f582a722d29eedb9b7267e7b102"
FOREIGN_ICON_MD5 = "db57c6a80840d6c31ded6c901563b3fc"
RELPATH_ICON_MD5 = "bf8198fc28a2b2402fda47497390f670"
# mapping of 
ICONS = {
  # failure case
  "this-icon-does-not-exist.png": None,
  # normal search
  "standard-app.png": STANDARD_ICON_MD5,
  # incorrect extension
  "standard-app.gif": STANDARD_ICON_MD5,
  # unthemed absolute search
  "/usr/share/icons/hicolor/64x64/apps/standard-app": STANDARD_ICON_MD5,
  # icons from other packages
  "foreign-icon": FOREIGN_ICON_MD5,
  # picks the bigger of two icons in ambigous quality directories
  # the best icon for "rel-path-app" is in /usr/share/pixmaps; it's in
  # /usr/share/icons/rel-dir/ for "rel-path-alt".
  "rel-path-app": RELPATH_ICON_MD5,
  "rel-path-alt": RELPATH_ICON_MD5 }


class IconFinderTest(unittest.TestCase):
    """
    Tests the proper operation of Index, which locates exact and themed
    icons using a ContentsIndex.
    """

    @classmethod
    def setUpClass(self):
        self.cache = ArchiveCache(RELEASE_PATH, IconFinder.prefixes)
        self.cache.load_arch("foo")

    def test_icon_search(self):
        """icon finder should find icons (obviously)"""
        finder = IconFinder()
        # check that all returned icon paths yield the correct icon's checksum
        for search_name, correct_checksum in ICONS.items():
            result = finder.search(search_name, self.cache)
            if correct_checksum == None:
                self.assertEqual(result, None)
                continue
            with open(result, "rb") as icon_file:
                checksum = hashlib.md5(icon_file.read()).hexdigest()
                self.assertEqual(checksum, correct_checksum)


if __name__ == "__main__":
    if not os.path.exists(RELEASE_PATH):
        subprocess.call("./build_test_archive")
    unittest.main()
