#!/usr/bin/env python3
import os.path
import logging
import subprocess
import sys
import unittest
sys.path.insert(0, "..")

from src.utils import load_deb_file

DEB_FILES = {
  # normal case extract
  ("archive/pool/main/standard/standard-app_1.0-1_foo.deb",
  "usr/share/applications/standard-app.desktop"): "ASCII text",
  # absolute symlink path extract
  ("archive/pool/alt/abs-symlink/abs-symlink-app_1.0-1_bar.deb",
   "usr/share/link_dir/needle.txt"): "ASCII text",
  # relative symlink path extract
  ("archive/pool/alt/symlink-icon/symlink-icon-app_1.0-1_bar.deb",
   "usr/share/icons/symlink-to-usrlibsym/symlink-icon-app.png"): "PNG image"}

FOREIGN_LINK_FILES = {
  ("archive/pool/main/foreign-symlink/foreign-symlink-app_1.0-1_bar.deb",
   "/usr/share/foreign_link_dir/needle.txt"): "/haystack/subdir/needle.txt"}


class TestLoadDebFile(unittest.TestCase):
    """
    Tests the proper operation of DebExtractor, which wraps over the
    complexity of obtaining files from deb packages.
    """
    def test_debs(self):
        """deb extractor can extract files from debs"""
        for (deb, path), debpathtype in DEB_FILES.items():
            temp = load_deb_file(path, deb)
            filetype = subprocess.check_output(["file", "-b", temp.name])
            temp.close()
            self.assertTrue(filetype.decode().startswith(debpathtype))

    def test_foreign_symlinks(self):
        """deb extractor returns paths for symlinks not in the deb"""
        for (deb, path), correct_return in FOREIGN_LINK_FILES.items():
            returned = load_deb_file(path, deb)
            self.assertEqual(returned, correct_return)


if __name__ == "__main__":
    unittest.main()
